[Pkg-owncloud-commits] [SCM] ocsync.git branch, upstream, updated. upstream/0.70.7

Sandro Knauß bugs at sandroknauss.de
Mon Apr 22 23:15:07 UTC 2013


The following commit has been merged in the upstream branch:
commit ed88399d15e63873d554f752217691afae5370e7
Author: Sandro Knauß <bugs at sandroknauss.de>
Date:   Mon Apr 22 23:44:11 2013 +0200

    Imported Upstream version 0.70.7

diff --git a/.tag b/.tag
index 2da250a..0ebdd35 100644
--- a/.tag
+++ b/.tag
@@ -1 +1 @@
-da5169bd55371844fa4749ec4bd38bebf7548e0d
+317b3149f31e4a8a780b6e47545a5e3ce7b009b0
diff --git a/CMakeLists.txt b/CMakeLists.txt
index 46a049f..1fbec54 100644
--- a/CMakeLists.txt
+++ b/CMakeLists.txt
@@ -8,7 +8,7 @@ set(APPLICATION_NAME ${PROJECT_NAME})
 
 set(APPLICATION_VERSION_MAJOR "0")
 set(APPLICATION_VERSION_MINOR "70")
-set(APPLICATION_VERSION_PATCH "6")
+set(APPLICATION_VERSION_PATCH "7")
 
 set(APPLICATION_VERSION "${APPLICATION_VERSION_MAJOR}.${APPLICATION_VERSION_MINOR}.${APPLICATION_VERSION_PATCH}")
 
diff --git a/ChangeLog b/ChangeLog
index 05cb9cb..68fca2c 100644
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,5 +1,10 @@
 ChangeLog
 ==========
+
+version 0.70.7  (released 2013-04-23)
+  * [Fixes] Resource exhaustion
+  * Better logging of statedb-related errors
+
 version 0.70.6  (released 2013-04-11)
   * [Fixes] Try to avoid to upload incomplete files
   * [Fixes] Increase read timeout to 300 seconds
diff --git a/src/vio/csync_vio.c b/src/vio/csync_vio.c
index fb4a48f..60c7c49 100644
--- a/src/vio/csync_vio.c
+++ b/src/vio/csync_vio.c
@@ -217,12 +217,15 @@ void csync_vio_shutdown(CSYNC *ctx) {
       (*ctx->module.finish_fn)(ctx->module.method);
     }
 
+/* GnuTLS, used on most linux distros, does not support dlclose without leaking. */
+#if defined(__APPLE__) || defined(_WIN32)
     /* close the plugin */
     dlclose(ctx->module.handle);
     ctx->module.handle = NULL;
 
     ctx->module.method = NULL;
     ctx->module.finish_fn = NULL;
+#endif
   }
 }
 

diff --git a/src/csync_statedb.c b/src/csync_statedb.c
index 47e668d..f530cd2 100644
--- a/src/csync_statedb.c
+++ b/src/csync_statedb.c
@@ -119,7 +119,7 @@ static int _csync_statedb_check(CSYNC *ctx, const char *statedb) {
     _csync_win32_hide_file(statedb);
     return 0;
   }
-  CSYNC_LOG(CSYNC_LOG_PRIORITY_ERROR, "%s %s", sqlite3_errmsg(db), statedb);
+  CSYNC_LOG(CSYNC_LOG_PRIORITY_ERROR, "sqlite3_open failed: %s %s", sqlite3_errmsg(db), statedb);
   sqlite3_close(db);
 
   return -1;
@@ -188,6 +188,8 @@ int csync_statedb_load(CSYNC *ctx, const char *statedb) {
    * its not there.
    */
   if (_csync_statedb_check(ctx, statedb) < 0) {
+    CSYNC_LOG(CSYNC_LOG_PRIORITY_NOTICE, "ERR: checking csync database failed - bail out.");
+
     rc = -1;
     goto out;
   }
@@ -199,19 +201,27 @@ int csync_statedb_load(CSYNC *ctx, const char *statedb) {
    * statedb.
    */
   if (asprintf(&statedb_tmp, "%s.ctmp", statedb) < 0) {
+    CSYNC_LOG(CSYNC_LOG_PRIORITY_NOTICE, "ERR: could not create statedb name - bail out.");
+
     rc = -1;
     goto out;
   }
 
   if (c_copy(statedb, statedb_tmp, 0644) < 0) {
+    CSYNC_LOG(CSYNC_LOG_PRIORITY_NOTICE, "ERR: Failed to copy statedb -> statedb_tmp - bail out.");
+
     rc = -1;
     goto out;
   }
 
   _csync_win32_hide_file( statedb_tmp );
 
   /* Open the temporary database */
   if (sqlite3_open(statedb_tmp, &ctx->statedb.db) != SQLITE_OK) {
+    const char *errmsg= sqlite3_errmsg(ctx->statedb.db);
+    CSYNC_LOG(CSYNC_LOG_PRIORITY_NOTICE, "ERR: Failed to sqlite3 open statedb - bail out: %s.",
+              errmsg ? errmsg : "<no sqlite3 errormsg>");
+
     rc = -1;
     goto out;
   }
@@ -199,19 +201,27 @@ int csync_statedb_load(CSYNC *ctx, const char *statedb) {
   _csync_win32_hide_file( statedb_tmp );
 
-  /* Open the temporary database */
+  /* Open or create the temporary database */
   if (sqlite3_open(statedb_tmp, &ctx->statedb.db) != SQLITE_OK) {
-- 
ocsync.git



More information about the Pkg-owncloud-commits mailing list